%global momorel 1

# Building the extra print profiles requires colprof, +4Gb of RAM and
# quite a lot of time. Don't enable this for test builds.
%define enable_print_profiles 0

# SANE is pretty insane when it comes to handling devices, and we get AVCs
# popping up all over the place.
%global enable_sane 0

%global build_print_profiles %{?enable_print_profiles}

Summary:   Color daemon
Name:      colord
Version: 1.3.5
Release: %{momorel}m%{?dist}
License:   GPLv2+ and LGPLv2+
Group:     Development/Libraries
URL:       http://www.freedesktop.org/software/colord/
Source0:   http://www.freedesktop.org/software/colord/releases/%{name}-%{version}.tar.xz
NoSource: 0

BuildRequires: dbus-devel
BuildRequires: docbook-utils
BuildRequires: gettext
BuildRequires: glib2-devel
BuildRequires: intltool
BuildRequires: systemd-devel
BuildRequires: lcms2-devel >= 2.6
BuildRequires: libgudev1-devel
BuildRequires: polkit-devel >= 0.103
BuildRequires: sqlite-devel
BuildRequires: gobject-introspection-devel
BuildRequires: vala-tools
BuildRequires: libgusb-devel >= 0.2.9
BuildRequires: gtk-doc
BuildRequires: color-filesystem
BuildRequires: bash-completion
BuildRequires: argyllcms

# for SANE support
%if 0%{?enable_sane}
BuildRequires: sane-backends-devel
BuildRequires: dbus-devel
%endif

Requires: color-filesystem
Requires: systemd-units
Requires(pre): shadow-utils
Requires: colord-libs%{?_isa} = %{version}-%{release}

# Self-obsoletes to fix the multilib upgrade path
Obsoletes: colord < 0.1.27-3

# obsolete separate profiles package
Obsoletes: shared-color-profiles <= 0.1.6-2
Provides: shared-color-profiles

%description
colord is a low level system activated daemon that maps color devices
to color profiles in the system context.

%package libs
Summary: Color daemon library

%description libs
colord is a low level system activated daemon that maps color devices
to color profiles in the system context.

%package devel
Summary: Development package for %{name}
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Obsoletes: colorhug-client-devel <= 0.1.13

%description devel
Files for development with %{name}.

%package devel-docs
Summary: Developer documentation package for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description devel-docs
Documentation for development with %{name}.

%package extra-profiles
Summary: More color profiles for color management that are less commonly used
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

# obsolete separate profiles package
Obsoletes: shared-color-profiles-extra <= 0.1.6-2
Provides: shared-color-profiles-extra

%description extra-profiles
More color profiles for color management that are less commonly used.
This may be useful for CMYK soft-proofing or for extra device support.

%prep
%setup -q

%build
# Set ~2 GiB limit so that colprof is forced to work in chunks when
# generating the print profile rather than trying to allocate a 3.1 GiB
# chunk of RAM to put the entire B-to-A tables in.
ulimit -Sv 2000000
%configure \
        --with-daemon-user=colord \
        --enable-gtk-doc \
        --enable-vala \
%if 0%{?build_print_profiles}
        --enable-print-profiles \
%else
        --disable-print-profiles \
%endif
%if 0%{?enable_sane}
        --enable-sane \
%endif
	--enable-libcolordcompat \
        --disable-static \
        --disable-rpath \
        --disable-examples \
        --disable-silent-rules \
        --disable-dependency-tracking

%make

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

# Remove static libs and libtool archives.
find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'

# databases
touch %{buildroot}%{_localstatedir}/lib/%{name}/mapping.db
touch %{buildroot}%{_localstatedir}/lib/%{name}/storage.db

%find_lang %{name}

%check
# known failure as of 1.1.5: colorhug/device-queue
make check || \
{ rc=$?; find . -name test-suite.log | xargs cat; } # exit $rc; }

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_localstatedir}/l/lib/%{name} -s /sbin/nologin \
    -c "User for %{name}" %{name}
exit 0

%post
/sbin/ldconfig
glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
/sbin/ldconfig
glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
%systemd_postun %{name}.service

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files -f %{name}.lang
%doc README.md AUTHORS NEWS COPYING
%{_libexecdir}/colord
%attr(755,colord,colord) %dir %{_localstatedir}/lib/colord
%attr(755,colord,colord) %dir %{_localstatedir}/lib/colord/icc
%{_bindir}/*
%{_datadir}/glib-2.0/schemas/org.freedesktop.ColorHelper.gschema.xml
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.ColorManager.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager*.xml
%{_datadir}/polkit-1/actions/org.freedesktop.color.policy
%{_datadir}/dbus-1/system-services/org.freedesktop.ColorManager.service
%{_datadir}/man/man1/*.1.*
%{_datadir}/colord
%{_datadir}/bash-completion/completions/colormgr
/usr/lib/udev/rules.d/*.rules
%{_libdir}/colord-sensors
%{_libdir}/colord-plugins
%ghost %attr(-,colord,colord) %{_localstatedir}/lib/colord/*.db
/usr/lib/systemd/system/colord.service

# session helper
%{_libexecdir}/colord-session
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorHelper.xml
%{_datadir}/dbus-1/services/org.freedesktop.ColorHelper.service

/%{_prefix}/lib/systemd/user/colord-session.service
/%{_prefix}/lib/tmpfiles.d/colord.conf

# sane helper
%if 0%{?enable_sane}
%{_libexecdir}/colord-sane
%endif

# common colorspaces
%dir %{_icccolordir}/colord
%{_icccolordir}/colord/AdobeRGB1998.icc
%{_icccolordir}/colord/ProPhotoRGB.icc
%{_icccolordir}/colord/SMPTE-C-RGB.icc
%{_icccolordir}/colord/sRGB.icc

# so we can display at least something in the default dropdown
%if 0%{?build_print_profiles}
%{_icccolordir}/colord/FOGRA39L_coated.icc
%endif

# monitor test profiles
%{_icccolordir}/colord/Bluish.icc

# named color profiles
%{_icccolordir}/colord/x11-colors.icc

%files libs
%doc COPYING
%{_libdir}/lib*.so.*
%{_libdir}/girepository-1.0/*.typelib

%files extra-profiles
%if 0%{?build_print_profiles}
%{_icccolordir}/colord/FOGRA27L_coated.icc
%{_icccolordir}/colord/FOGRA28L_webcoated.icc
%{_icccolordir}/colord/FOGRA29L_uncoated.icc
%{_icccolordir}/colord/FOGRA30L_uncoated_yellowish.icc
%{_icccolordir}/colord/FOGRA40L_SC_paper.icc
%{_icccolordir}/colord/FOGRA45L_lwc.icc
%{_icccolordir}/colord/FOGRA47L_uncoated.icc
%{_icccolordir}/colord/GRACoL*.icc
%{_icccolordir}/colord/IFRA26S_2004_newsprint.icc
%{_icccolordir}/colord/SNAP*.icc
%{_icccolordir}/colord/SWOP*.icc
%endif

# other colorspaces not often used
%{_icccolordir}/colord/AppleRGB.icc
%{_icccolordir}/colord/BestRGB.icc
%{_icccolordir}/colord/BetaRGB.icc
%{_icccolordir}/colord/BruceRGB.icc
%{_icccolordir}/colord/CIE-RGB.icc
%{_icccolordir}/colord/ColorMatchRGB.icc
%{_icccolordir}/colord/DonRGB4.icc
%{_icccolordir}/colord/ECI-RGBv1.icc
%{_icccolordir}/colord/ECI-RGBv2.icc
%{_icccolordir}/colord/EktaSpacePS5.icc
%{_icccolordir}/colord/Gamma*.icc
%{_icccolordir}/colord/NTSC-RGB.icc
%{_icccolordir}/colord/PAL-RGB.icc
%{_icccolordir}/colord/SwappedRedAndGreen.icc
%{_icccolordir}/colord/WideGamutRGB.icc

# other named color profiles not generally useful
%{_icccolordir}/colord/Crayons.icc

%files devel
%defattr(-, root, root)
%{_includedir}/%{name}-1
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/colorhug.pc
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}compat.so
%{_libdir}/lib%{name}private.so
%{_libdir}/libcolorhug.so
%{_datadir}/gir-1.0/ColorHug-1.0.gir
%{_datadir}/gir-1.0/Colord-1.0.gir
%{_datadir}/vala/vapi/%{name}.vapi

%files devel-docs
%defattr(-, root, root)
%{_datadir}/gtk-doc/html/%{name}

%changelog
* Fri Mar 17 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (1.3.5-1m)
- update to 1.3.5

* Thu Apr 07 2016 Yohsuke Ooi <meke@momonga-linux.org>
- (1.2.12-1m)
- update to 1.2.12

* Mon Jun 22 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (1.2.11-1m)
- update to 1.2.11

* Thu Apr  9 2015 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (1.2.10-1m)
- update to 1.2.10

* Tue Mar 10 2015 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (1.2.9-1m)
- update to 1.2.9
- build against libgusb-0.2.4

* Sun Oct 19 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.2.4-1m)
- update to 1.2.4

* Fri Sep 26 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.2.3-2m)
- update

* Mon Jun 02 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.2.1-1m)
- update to 1.2.1

* Sun Apr 06 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.2.0-1m)
- update to 1.2.0

* Wed Mar 05 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.1.7-1m)
- update to 1.1.7

* Thu Feb 20 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.1.6-1m)
- update to 1.1.6

* Mon Dec 30 2013 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.1.5-2m)
- fix systemd support

* Sat Dec 28 2013 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.1.5-1m)
- update to 1.1.5

* Sat Aug 31 2013 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.1.1-1m)
- update to 1.1.1
- revise spec; remove unused subpackage definition

* Mon May 20 2013 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.1.34-1m)
- version 0.1.34
- add some Requires
- set --enable-vala to %%configure
- modify %%install
- add %%clean section
- modify %%pre, %%post, %%preun and %%postun
- rewrite %%files

* Fri Jul 06 2012 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.1.22-1m)
- reimport from fedora

* Thu Jun 28 2012 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.1.15-2m)
- rebuild for glib 2.33.2

* Sun Nov 27 2011 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.1.15-1m)
- [SECURITY] CVE-2011-4349
- update to 0.1.15

* Sat Nov  5 2011 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.1.14-1m)
- update to 0.1.14

* Wed Oct  5 2011 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.1.13-1m)
- update to 0.1.13

* Fri Sep 16 2011 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.1.12-1m)
- update to 0.1.12

* Tue Sep 13 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.1.10-2m)
- fix build failure on x86_64

* Sat Sep 10 2011 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.1.10-1m)
- initial build
